<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: PointerCreateForm.php 4606 2006-07-12 22:41:37Z morgabra $

/**
 *  PointerCreateForm.php - contains the {@link PointerCreateForm} class
 *
 *  @author     $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  This form is used to create Pointers.
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class PointerCreateForm extends MaintainForm
{

//{{{   vars

    /**
     *  This var maps the form labels to the dbdo's variables and vice versa.
     */
    var $map = array("Hostname"=>"hostname",
                    "Pointer_Type"=>"type",
                    "Time_to_Live"=>"ttl",
                    "Status"=>"enabled",
                    "IP_Address"=>"ip");

//}}}
//{{{   form_hidden()

    /**
     *  This function adds the necessary hidden elements to the form
     *
     *  @return FEHidden    A hidden form element to pass necessary information
     */
    function form_hidden()
    {
        $hidden = new FEHidden("action","create");

        $this->add_element($hidden);

        return $this->element_form("action");
    }

//}}}
//{{{   form_init_elements()

    /**
     *  This method initializes all the form fields
     */
    function form_init_elements()
    {
        $ipaddy     = new FEText(_("IP Address"), true);
        $hostname   = new FEText(_("Hostname"),true);
        $ttl        = new FEText(_("Time to Live"),true);
        $type       = new FEListBox(_("Pointer Type"));

        $type->set_list_data(array("Reverse"=>"reverse",
                                    "Forward"=>"forward"));


        $this->add_elements($ipaddy, $hostname, $ttl, $type);
        $this->set_action($_SERVER["SCRIPT_NAME"]);
    }

//}}}
//{{{ form_init_data()
    function form_init_data()
    {
        global $conf;
        $this->set_element_value(_("Time to Live"), $conf['soa']['default_pointer_ttl']);
    }
//}}}
//{{{   form_backend_validation()

    /**
     *  This method does the validation to assure that the values are ok for 
     *  processing in the form_action method.
     *
     *  @return Boolean     true if the data is valid
     */
    function form_backend_validation()
    {
        $pntr = new Pointer($_REQUEST['id']);
        $res = true;

        $init = $this->get_all_element_values();
       
        $pntr->setAll();
        $pntr->setFrom($this->remap($init, DBDO));
        
        $pntr->setZone($_SESSION['zone']);
       
        $valid = $pntr->validate();

        if($valid !== true) {
            $errors = $this->remap($valid,FORM);
            $res = false;
            foreach($errors as $label=>$error) {
                if($error !== true)
                    $this->add_error($label, $error);
            }
        }

        return $res;
    }

//}}}
//{{{   form_action()

    /**
     *  This method is what gets run when validation is successfully run.  It 
     *  handles the actual processing of the valid data.
     *
     *  @return Boolean     true if processing was successful
     */
    function form_action()
    {
        global $user;
        $res = true;
        
        switch(strtolower($this->get_action())) {
        
        case _('submit'):
            $pntr = new Pointer();
            $pntr->query("BEGIN");
            
            $init = $this->get_all_element_values();
        
            $pntr->setAll();
            $pntr->setFrom($this->remap($init, DBDO));
            $pntr->zone = $_SESSION['zone'];

            if($pntr->insert() === false) {
                $pntr->query("ROLLBACK");
                $res = false;
                $this->add_error(_("ERROR"),
                            _("Pointer could not be written to the database"));
            } else {
                $pntr->query("COMMIT");
                $pntr->write_history(_("Pointer Created"), ACTION_CREATE, $user->username, $_SESSION['zone']);
            }
            break;

        case _("cancel"):
            header("Location: pointer.php");
            break;

        default:
            die_hard(_("Invalid form action"));
        
        }

        return $res;
        
    }

//}}}
//{{{   form_success()

    /**
     *  This method is what gets run when the form action is successful.  In this
     *  instance it is a redirect back to the pointer list.
     */
    function form_success()
    {
        $div = html_div('msuccess');
        $div->add(_("Successfully Created Pointer"), html_br());
        $indlink = html_a(web_root()."index.php", _("[Return to Index]"));
        $sublink = html_a(web_root()."pointer.php", _("[Return to Pointer List]"));

        $div->add($indlink, $sublink);

        return $div;
    }

//}}}

}

?>
