<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Zack Bartel <bartel@osuosl.org                              |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: RangeSplitForm.php 3964 2006-01-03 21:49:51Z bartel $

/**
 *  RangeSplitForm.php - contains the {@link RangeSplitForm} class
 *
 *  @author $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

class RangeSplitForm extends MaintainForm
{

    var $_range;
//{{{   form_init_elements()

    /**
     *  This method initializes the form elements that will be used.  Please refer
     *  to {@link RangeSplitForm} for more information.
     */
    function form_init_elements()
    {
        $ips = $this->getIPs();
        
        $frs = new FEText(_("First Range Start"), false);
        $frs->set_readonly(true);
        
        $fre = new FEListBox(_("First Range End"), false);
        $fre->set_list_data($ips);

        $srs = new FEListBox(_("Second Range Start"), false);
        $srs->set_list_data($ips);

        $sre = new FEText(_("Second Range End"), false);
        $sre->set_readonly(true);
       
        $this->add_elements($frs, $fre, $srs, $sre);
    }

//}}}
//{{{   form_init_data()
   
    /**
     *  This method sets the initial values for the form elements based off of
     *  which Range we're updating.
     */
    function form_init_data()
    {
        $range = $this->getRange();
        $this->set_element_value(_("First Range Start"), $range->getStart());
        $this->set_element_value(_("Second Range End"), $range->getEnd());
    }

//}}}
//{{{   form_hidden()

    /**
     *  This method establishes the hidden elements for the form.
     *
     *  @return Container   Container with the hidden elements for the form
     */
    function form_hidden()
    {
        $action =  new FEHidden(_("action"), $_REQUEST['action']);
        $id = new FEHidden(_("id"), $_REQUEST['id']);

        $this->add_elements($action, $id);

        return container($this->element_form(_('action')), $this->element_form(_('id')));                                
    }

//}}}
//{{{   form_action()

    /**
     *  This method handles validation of the split and then
     *  uses Range::split_range() to perform the split
     *
     *  @return Boolean True if action succeeds
     */
    function form_action()
    {
        global $user;
        
        $res = true;
        
        $this->getRange();
        switch(strtolower($this->get_action())) {

        case 'submit':
            $vals = $this->get_all_element_values();
            //$frs = IP::ip2int($vals[_("First_Range_Start")]);
            //$fre = $vals[_("First_Range_End")];
            $srs = $vals[_("Second_Range_Start")];
            //$sre = IP::ip2int($vals[_("Second_Range_End")]);
            $success = Range::split_range($_REQUEST['id'], $srs);
            if (PEAR::isError($success))    {
                $this->add_error(_("ERROR"), $success->message);
                $res = false;
            }
            break;
            
        default:
            die_hard(_("Invalid form action"));
            break;
        }

        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  This displays a happy message to the user letting them know that the update
     *  worked.
     *
     *  @return DIVTag  $div    Div that contains the success message
     */
    function form_success() 
    {
        $div = html_div('rsuccess');
        $div->add(_("Successfully Split Range"));
     //   $low = html_a($_SERVER['SCRIPT_NAME']."?action=edit&id=".$_REQUEST['id'], _("[Edit low Range]"));
       // $high = html_a($_SERVER['SCRIPT_NAME']."?action=edit&id=".$_REQUEST['id'], _("[Edit low Range]"));
        $list = html_a($_SERVER['SCRIPT_NAME']."?action=show", _("[Return to Range List]"));
        $index = html_a(web_root()."index.php", _("[Return to Home]"));
        $div->add(container(html_br(), $index, $list));
        return $div;
    }

//}}}
//{{{ form_backend_validation()
    /**
     *  Validate selected ip addresses to ensure valid range. Return true or false depending on
     *  validity (who would have thunk it!)
     *
     *
     *
     */
    function form_backend_validation()
    {
        $result = true;
        
        /* Grab form values */
        $vals = $this->get_all_element_values();
        $frs = IP::ip2int($vals[_("First_Range_Start")]);
        $fre = $vals[_("First_Range_End")];
        $srs = $vals[_("Second_Range_Start")];
        $sre = IP::ip2int($vals[_("Second_Range_End")]);
        
        if ($fre >= $srs || $frs >= $fre || $srs >= $sre)   {
            $this->add_error(_("Error"), _("Ranges Overlap"));
            $result = false;
        }
    

        unset($this->_range);
        return $result;
    }
//}}}
//{{{   getIPs()

    /**
     *  This function returns a sorted list of ip addresses in the current range ($_range)
     *
     *
     *  @return array $result array of results in the form $result[$ip] = $intip
     */
    function getIPs()
    {
        $result = array();
        $this->getRange();
        $start = $this->_range->start;
        $end = $this->_range->end;
        $current = $start;
        
        while ($current <= $end)    {
            $result[IP::int2ip($current)] = $current;
            $current++;
        }
        return $result;
    }
//}}}
  
//{{{   getRange()
    /**
     *  This function sets the value ot $this->_range to the Range object 
     *  with the pk of $_REQUEST['id']
     *
     *  
     *  @return array $this->_range
     */
    function getRange()
    {
        if (!$this->_range) {
            $this->_range = new Range($_REQUEST['id']);
        }
        return $this->_range;
    }
//}}}
}

?>
