<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Zack Bartel  <bartel@osuosl.org>                            |
// +------------------------------------------------------------------------+
// $Id: RangeZoneBulkDeleteConfirm.php 3985 2006-1-19 22:53:35Z bartel $

/**
 *  RangeZoneBulkDeleteConfirm.php - This file contains the 
 *                                  {@link RangeZoneBulkDeleteConfirm} class
 *
 *  @author $Author:$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

/**
 *  This class is responsible for handling zone_range delete confirmations in
 *  zone.php when showing ranges associated with zones
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class RangeZoneBulkDeleteConfirm extends FormContent
{

/* Variables */
//{{{   Vars

    /**
     *  IDs in the database of the rows in question
     */
    var $ids;

//}}}
/* Functions */
//{{{   Constructor

    function RangeZoneBulkDeleteConfirm($ids)
    {
        $this->ids = $ids;
    }

//}}}
//{{{   form_init_elements()

    function form_init_elements()
    {
        $action =   new FEHidden("action", $_REQUEST['action']);
                
        $this->add_element(new FEHidden("ids", serialize($this->ids)));
        $this->add_element($action);
    }

//}}}
//{{{   form()

    function form()
    {
        $div = html_div("delconfirm");
        $this->set_cancel_action($_SERVER['SCRIPT_NAME']);
        
        $div->add(_("You are going to delete this Range from the following Range(s):"));
        $div->add(html_br());

        if (!is_array($this->ids))
            header("Location: ".web_root()."zone.php?action=edit&id=".$_REQUEST['id']);
        foreach($this->ids as $objid) {
            $zr = DB_DataObject::Factory('zone_range');
            $zr->id = $objid;
            $zr->find(1);
            $zn = new Range($zr->range);
            $div->add($zn->getDisplay(), html_br());
        }
        
        //Need to know where to go (coming from) after the delete.
        $rngid = new FEHidden('range_id', $zr->range);
        $this->add_element($rngid);
        
        $zoneid = new FEHidden('id', $zr->zone);
        $this->add_element($zoneid);
        
        $div->add(html_br(), $this->add_action(_('Confirm')), $this->add_cancel());
        $div->add($this->element_form("action"),$this->element_form("ids"),
                    $this->element_form('range_id'), $this->element_form('id'));

        return $div;
    }

//}}}
//{{{   form_action()

    function form_action()
    {
        global $user;
        $res = true;

        switch(strtolower($this->get_action())) {

        case 'confirm':
            $zrids = unserialize(stripslashes($_REQUEST['ids']));
            foreach($zrids as $zrid) {
                $zr = DB_DataObject::Factory('zone_range');
                $zr->query("BEGIN");
                $zr->id =$zrid;
                $zr->find(1);
                if($zr->delete() === false) {
                    $zr->query("ROLLBACK");
                    $this->add_error(_("ERROR"), _("Could not delete entry from DB"));
                    $res = false;
                } else {
                    $zr->query("COMMIT");
                    $zr->write_history(_("Range Deleted From Zone"), 
                                        ACTION_DELETE, $user->username, $zr->zone);
                }
            }
            break;

        default:
            $this->add_error(_("ERROR"),_("Invalid form action"));
            break;
        }

        return $res;
    }

//}}}

//{{{   form_backend_validation()
    /**
     *  This functions checks to see if it is ok to
     *  delete the requested zone_range mapping(s).
     *  A range must have at least one zone mapped to it.
     *
     *  @return Boolean     True if delete operation is valid
     */
    function form_backend_validation()
    {
        $result = false;
        /* How many does the user want to delete? */
        $idz = unserialize(stripslashes($_REQUEST['ids']));
        $zr_count = count($idz);

        /* How many zones associated with this range in? */
        $rid =  $_REQUEST['range_id'];
        $zr = DB_DataObject::Factory('zone_range');
        $zr->range = $rid;
        //$zr->enabled = 1        //Not sure ? 
        $total = $zr->count();

        /* Is there at least one left? */
        if ($total > $zr_count)
            $result = true;
        else    {
            $result = false;
        
            $this->add_error(_("Error"), _("All ranges must be assoicated with at least one zone"));
        }
        return $result;      
    }


//}}}
//{{{   form_success()
    function form_success()
    {
        $div = html_div("success");
        $cont = html_a("zone.php?action=edit&amp;id=".$_REQUEST['id'],_("[Continue]"));
        $div->add(container(html_br(), _("Ranges sucessfully removed from zone"), html_br(), $cont));
        return $div;
    }

}
//{{{
?>
